@@ -64,7 +64,7 @@ discover_nhdplus_id <- function(point = NULL, nldi_feature = NULL) {
 }
 
 #' @noRd
-get_nhdplus_byid <- function(comids, layer) {
+get_nhdplus_byid <- function(comids, layer, streamorder = NULL) {
 
   ows_url <- get("geoserver_ows_root", envir = nhdplusTools_env)
 
@@ -116,7 +116,7 @@ get_nhdplus_byid <- function(comids, layer) {
 }
 
 #' @noRd
-get_nhdplus_bybox <- function(box, layer) {
+get_nhdplus_bybox <- function(box, layer, streamorder = NULL) {
 
   valid_layers <- c("nhdarea", "nhdwaterbody", "catchmentsp", "nhdflowline_network")
 
@@ -132,21 +132,43 @@ get_nhdplus_bybox <- function(box, layer) {
 
   # nolint start
 
-  filter_xml <- paste0('<?xml version="1.0"?>',
-                       '<wfs:GetFeature xmlns:wfs="http://www.opengis.net/wfs" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:gml="http://www.opengis.net/gml" service="WFS" version="1.1.0" outputFormat="application/json" xsi:schemaLocation="http://www.opengis.net/wfs http://schemas.opengis.net/wfs/1.1.0/wfs.xsd">',
-                       '<wfs:Query xmlns:feature="http://wmadata" typeName="feature:',
-                       layer, '" srsName="EPSG:4326">',
-                       '<ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">',
-                       '<ogc:BBOX>',
-                       '<ogc:PropertyName>the_geom</ogc:PropertyName>',
-                       '<gml:Envelope>',
-                       '<gml:lowerCorner>',bbox[2]," ",bbox[1],'</gml:lowerCorner>',
-                       '<gml:upperCorner>',bbox[4]," ",bbox[3],'</gml:upperCorner>',
-                       '</gml:Envelope>',
-                       '</ogc:BBOX>',
-                       '</ogc:Filter>',
-                       '</wfs:Query>',
-                       '</wfs:GetFeature>')
+  filter_1 <- paste0('<?xml version="1.0"?>',
+                     '<wfs:GetFeature xmlns:wfs="http://www.opengis.net/wfs" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:gml="http://www.opengis.net/gml" service="WFS" version="1.1.0" outputFormat="application/json" xsi:schemaLocation="http://www.opengis.net/wfs http://schemas.opengis.net/wfs/1.1.0/wfs.xsd">',
+                     '<wfs:Query xmlns:feature="http://wmadata" typeName="feature:',
+                     layer, '" srsName="EPSG:4326">',
+                     '<ogc:Filter xmlns:ogc="http://www.opengis.net/ogc">')
+
+  bbox_xml <- paste0('<ogc:BBOX>',
+                     '<ogc:PropertyName>the_geom</ogc:PropertyName>',
+                     '<gml:Envelope>',
+                     '<gml:lowerCorner>',bbox[2]," ",bbox[1],'</gml:lowerCorner>',
+                     '<gml:upperCorner>',bbox[4]," ",bbox[3],'</gml:upperCorner>',
+                     '</gml:Envelope>',
+                     '</ogc:BBOX>')
+
+  filter_2 <- paste0('</ogc:Filter>',
+                     '</wfs:Query>',
+                     '</wfs:GetFeature>')
+
+  if(is.null(streamorder)) {
+    filter_xml <- paste0(filter_1,
+                         bbox_xml,
+                         filter_2)
+  } else {
+    filter_xml <- paste0(filter_1,
+                         '<ogc:And>',
+                         '<ogc:PropertyIsGreaterThanOrEqualTo>',
+                         '<ogc:PropertyName>',
+                         'streamorde',
+                         '</ogc:PropertyName>',
+                         '<ogc:Literal>',
+                         streamorder,
+                         '</ogc:Literal>',
+                         '</ogc:PropertyIsGreaterThanOrEqualTo>',
+                         bbox_xml,
+                         '</ogc:And>',
+                         filter_2)
+  }
 
   # nolint end
 
